@@ -92,7 +92,7 @@ def new_deploy_assignment(base_name, INSTRUCTOR_REPORT_CLASS, INSTRUCTOR_BASE, I
     But what? 
     """
 
-    INSTRUCTOR_REPORT_CLASS.pack_imports
+    # INSTRUCTOR_REPORT_CLASS.pack_imports
     report = INSTRUCTOR_REPORT_CLASS()
 
     # INSTRUCTOR_REPORT_CLASS
@@ -104,7 +104,7 @@ def new_deploy_assignment(base_name, INSTRUCTOR_REPORT_CLASS, INSTRUCTOR_BASE, I
     # deploy_assignment()
     # deploy_directly = COURSES_BASE != None
     if COURSES_BASE == None:
-        COURSES_BASE = os.getcwd() + "/tmp"
+        COURSES_BASE = os.getcwd() + "/../tmp"
         if not os.path.exists(COURSES_BASE):
             os.mkdir(COURSES_BASE)
 
@@ -124,9 +124,6 @@ def new_deploy_assignment(base_name, INSTRUCTOR_REPORT_CLASS, INSTRUCTOR_BASE, I
     total_ = res['total'][1]
     problems = []
     problems.append(dict(name='Unitgrade score', description='', max_score=total_, optional='false'))
-    # for k, q in res['details'].items():
-    #     problems.append(dict(name=q['title'], description='', max_score=q['possible'], optional='true'))
-    # problems.append(dict(name="Autograding Total", description='The description (set in autolab.py)', max_score=total_, optional='false'))
     print(problems)
     sc = [('Total', res['total'][0])] + [(q['title'], q['obtained']) for k, q in res['details'].items()]
     ss = ", ".join([f'"{t}": {s}' for t, s in sc])
@@ -157,11 +154,13 @@ def new_deploy_assignment(base_name, INSTRUCTOR_REPORT_CLASS, INSTRUCTOR_BASE, I
     INSTRUCTOR_REPORT_FILE = INSTRUCTOR_GRADE_FILE[:-9] + ".py"
 
     print("Making data...")
+    student_token_src_filename = os.path.basename(STUDENT_TOKEN_FILE)
     # /home/tuhe/Documents/unitgrade_private_v1/examples/example_simplest/instructor/programs/report5.py"
     data = {
         'base_name': base_name,
         'display_name': paths2report(INSTRUCTOR_BASE, INSTRUCTOR_REPORT_FILE).title,
         'handin_filename': handin_filename,
+        # 'student_token_file': STUDENT_TOKEN_FILE,
         'autograde_image': autograde_image_tag,
         'src_files_to_handout': ['driver_python.py', 'student_sources.zip', handin_filename,
                                  os.path.basename(docker_helpers.__file__),
@@ -171,6 +170,7 @@ def new_deploy_assignment(base_name, INSTRUCTOR_REPORT_CLASS, INSTRUCTOR_BASE, I
         'problems': problems,
         'student_should_upload_token': student_should_upload_token,
         'homework_file': homework_file,
+        'student_token_src_filename': student_token_src_filename,
         # 'homework_file_basename':
     }
     print("> Running jinja2")
@@ -189,6 +189,7 @@ def new_deploy_assignment(base_name, INSTRUCTOR_REPORT_CLASS, INSTRUCTOR_BASE, I
     # Copy the student grade file to remove.
     shutil.copyfile(INSTRUCTOR_GRADE_FILE, f"{LAB_DEST}/src/{os.path.basename(INSTRUCTOR_GRADE_FILE)}")
     shutil.copyfile(STUDENT_TOKEN_FILE, f"{LAB_DEST}/src/{handin_filename}")
+    shutil.copyfile(STUDENT_TOKEN_FILE, f"{LAB_DEST}/src/{student_token_src_filename}")
     import pathlib
     print("> Making archive..")
     # zip_base_dir = pathlib.Path(os.path.relpath(STUDENT_GRADE_FILE, STUDENT_BASE)).parent
@@ -202,14 +203,13 @@ def new_deploy_assignment(base_name, INSTRUCTOR_REPORT_CLASS, INSTRUCTOR_BASE, I
     os.mkdir(LAB_DEST + "/test-autograder")  # Otherwise make clean will screw up.
     print(f"cd {LAB_DEST} && make && cd {CURDIR}")
     cmd = f"cd {LAB_DEST} && make && cd {CURDIR}"
-    # import os
 
     os.system(f"cd {LAB_DEST} && make && cd {CURDIR}")
-    os.system(f"cd {LAB_DEST} && make handout")
-    from slider.latexutils import latexmk
-    import subprocess
-    s = subprocess.check_output(cmd, shell=True)
-
+    # os.system(f"cd {LAB_DEST} && make handout")
+    # from slider.latexutils import latexmk
+    # import subprocess
+    # s = subprocess.check_output(cmd, shell=True)
+    print("Ran make command...")
     if output_tar is None:
         output_tar = os.getcwd() + "/" + base_name + ".tar"
     print("Making archive")
