@@ -7,6 +7,7 @@ from unitgrade_private.autolab.autolab import format_autolab_json
 from unitgrade_private.docker_helpers import student_token_file_runner
 from unitgrade_private import load_token
 import time
+import unitgrade_private
 
 verbose = False
 tag = "[driver_python.py]"
@@ -14,6 +15,10 @@ tag = "[driver_python.py]"
 if not verbose:
     print("="*10)
     print(tag, "Starting unitgrade evaluation...")
+import unitgrade
+print(tag, "Unitgrade version", unitgrade.version.__version__)
+print(tag, "Unitgrade-devel version", unitgrade_private.version.__version__)
+
 
 sys.stderr = sys.stdout
 wdir = os.getcwd()
@@ -25,7 +30,7 @@ def pfiles():
     print("---")
 
 handin_filename = "{{handin_filename}}"
-student_token_file = '{{handin_filename}}'
+student_token_file = '{{handin_filename if student_should_upload_token else student_token_src_filename}}'
 instructor_grade_script = '{{instructor_grade_file}}'
 grade_file_relative_destination = "{{grade_file_relative_destination}}"
 host_tmp_dir = wdir + "/tmp"
