@@ -33,12 +33,12 @@ def download_docker_images(destination=None):
                 shutil.copytree(tmp_dir, dest)
 
 
-def compile_docker_image(Dockerfile, tag=None):
+def compile_docker_image(Dockerfile, tag=None, no_cache=False):
     assert os.path.isfile(Dockerfile)
     base = os.path.dirname(Dockerfile)
     if tag == None:
         tag = os.path.basename(base)
-    os.system(f"cd {base} && docker build --tag {tag} .")
+    os.system(f"cd {base} && docker build {'--no-cache' if no_cache else ''} --tag {tag} .")
     return tag
 
 
